Module blaxel.models.time_to_first_token_over_time_metrics
==========================================================

Classes
-------

`TimeToFirstTokenOverTimeMetrics(time_to_first_token_over_time: blaxel.types.Unset | ForwardRef('RequestDurationOverTimeMetric') = <blaxel.types.Unset object>)`
:   Time to first token over time metrics
    
    Attributes:
        time_to_first_token_over_time (Union[Unset, RequestDurationOverTimeMetric]): Request duration over time metric
    
    Method generated by attrs for class TimeToFirstTokenOverTimeMetrics.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `time_to_first_token_over_time`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :